const Booking_participantsDBApi = require('../../db/api/booking_participants');
const ValidationError = require('./notifications/errors/validation');
const getDbInstance = require("../../db/initialize");

module.exports = class Booking_participantsService {
  static async create(data, currentUser) {
    const db = await getDbInstance();
    const transaction = await db.sequelize.transaction();
    try {
      const data = await Booking_participantsDBApi.create(data, {
        currentUser,
        transaction,
      });

      await transaction.commit();

      return data;

    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }
  static async update(data, id, currentUser) {
    const db = await getDbInstance();
    const transaction = await db.sequelize.transaction();
    try {
      let booking_participants = await Booking_participantsDBApi.findBy(
        { id },
        { transaction },
      );

      if (!booking_participants) {
        throw new ValidationError('booking_participantsNotFound');
      }

      await Booking_participantsDBApi.update(id, data, {
        currentUser,
        transaction,
      });

      await transaction.commit();
      return booking_participants;
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async remove(id, currentUser) {
    const db = await getDbInstance();
    const transaction = await db.sequelize.transaction();

    try {
      if (currentUser.role !== 'admin') {
        throw new ValidationError('errors.forbidden.message');
      }

      await Booking_participantsDBApi.remove(id, {
        currentUser,
        transaction,
      });

      await transaction.commit();
      return { message: 'success'};
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }
};
