const PujarisDBApi = require('../../db/api/pujaris');
const Karuser_pujari_mappingsDBApi = require('../../db/api/karuser_pujari_mappings');
const ValidationError = require('./notifications/errors/validation');
const WatiService = require('../services/wati');
const EmailSender = require('./email');
const getDbInstance = require("../../db/initialize");
module.exports = class PujarisService {
  static async create(data, currentUser) {
    const db = await getDbInstance();
    const transaction = await db.sequelize.transaction();
    try {
      const pujariCreateResponse = await PujarisDBApi.create(data, {
        currentUser,
        transaction,
      });

      const karusersPujariMappings = data?.karusers.map((user) => {
        return {
          pujari_id: pujariCreateResponse?.id,
          karuser_id: user.id,
        };
      });

      await Karuser_pujari_mappingsDBApi.create(karusersPujariMappings, {
        currentUser,
        transaction,
      });

      const watiObj = new WatiService();
      const mailSender = new EmailSender();

      // NOTIFY ADMIN
      try {
        await mailSender.sendEmail({
          dynamicData: {},
          mailProps: { to: mailSender.adminMail },
          template: mailSender.htmlTemplates.PUJARI_CREATE__ADMIN,
        });

        // NOTIFY USER
        WatiService.sendWhatsappMessage(
          data.phone_number,
          watiObj.templates.pujariCreated,
          [
            {
              name: 'name',
              value: `${data.name} ${data.surname}`,
            },
          ],
        );
      } catch (error) {
        console.log('error', error);
      }

      await transaction.commit();

      return { message: 'success' };
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async update(data, id, currentUser) {
    const db = await getDbInstance();
    const transaction = await db.sequelize.transaction();
    try {
      let pujaris = await PujarisDBApi.findBy({ id });

        console.log('===== update pujari payload =====', data);

        if (!pujaris) {
            throw new ValidationError('pujarisNotFound');
        }

        await PujarisDBApi.update(id, data, {
            currentUser,
            transaction, // Ensure transaction is passed correctly
        });

        await Karuser_pujari_mappingsDBApi.remove(id, {
            currentUser,
            transaction,
        });

        const karusersPujariMappings = data?.karusers.map((user) => {
            return {
                pujari_id: id,
                karuser_id: user.id,
            };
        });

        await Karuser_pujari_mappingsDBApi.create(karusersPujariMappings, {
            currentUser,
            transaction,
        });

        await transaction.commit();
        return pujaris;
    } catch (error) {
        await transaction.rollback();
        throw error;
    }
}


  static async remove(id, currentUser) {
    const db = await getDbInstance();
    const transaction = await db.sequelize.transaction();

    try {
      await PujarisDBApi.remove(id, {
        currentUser,
        transaction,
      });

      await transaction.commit();
      return { message: 'success' };
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async getPujariDetails(id) {
      const result = await PujarisDBApi.findPujari(id);
      return result;
  }
};
