import { MiddlewareConsumer, Module, NestModule } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';
import { ServeStaticModule } from '@nestjs/serve-static';
import { join } from 'path';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { LoggerMiddleware } from './middleware/logger';
import { BookingsModule } from './pujari/bookings/bookings.module';
import { EmailService } from './pujari/email-config/email.service';
import { PujaProcedureModule } from './pujari/puja-procedures/puja-procedure.module';
import { PujariModule } from './pujari/pujari.module';
import { LoginModule } from './login/login.module';
import { HttpModule } from '@nestjs/axios';
import { SamagriModule } from './pujari/samagri/samagri.module';
import { RazorpayModule } from './razorpay/razorpay.module';
import { OrdersController } from './orders/orders.controller';
import { AdminModule } from './admin/admin.module';
@Module({
  imports: [
    ServeStaticModule.forRoot({
      rootPath: join(__dirname, '..', '/assets'),
      serveRoot: '/assets/',
    }),
    ConfigModule.forRoot({
      isGlobal: true,
    }),
    PujariModule,
    HttpModule,
    BookingsModule,
    ConfigModule.forRoot(),
    PujaProcedureModule,
    LoginModule,
    SamagriModule,
    RazorpayModule,
    AdminModule,
  ],
  controllers: [AppController, OrdersController],
  providers: [AppService, EmailService],
})
export class AppModule implements NestModule {
  configure(consumer: MiddlewareConsumer) {
    consumer.apply(LoggerMiddleware).forRoutes('*');
  }
}
