import { Injectable } from '@nestjs/common';
import { ConfigService as NestConfigService } from '@nestjs/config';

@Injectable()
export class ConfigService {
  constructor(private configService: NestConfigService) {}

  get(key: string): string | undefined {
    return this.configService.get<string>(key);
  }

  getRequired(key: string): string {
    const value = this.get(key);
    if (!value) {
      throw new Error(`Required config key "${key}" is missing`);
    }
    return value;
  }

  getNumber(key: string): number | undefined {
    const value = this.configService.get<string>(key);
    return value ? Number(value) : undefined;
  }

  getBoolean(key: string): boolean {
    return this.configService.get<string>(key)?.toLowerCase() === 'true';
  }
} 