const getDbInstance = require("../initialize");
const Utils = require("../utils");
const Sequelize = require("sequelize");
const Op = Sequelize.Op;

module.exports = class PujaModelsProceduresMappingsDBApi {
  static async create(data) {
    const db = await getDbInstance();

    const puja_model_procedure_mappings =
      await db.puja_model_procedure_mappings.bulkCreate(data, {
        returning: true,
      });

    return puja_model_procedure_mappings;
  }

  static async findAll(filter, options) {
    const db = await getDbInstance();
    var limit = filter.limit || 0;
    var offset = 0;
    const currentPage = +filter.page;

    offset = currentPage * limit;


    const transaction = (options && options.transaction) || undefined;
    let where = {};
    let include = [];

    if (filter) {
      if (filter.id) {
        where = {
          ...where,
          ["id"]: Utils.uuid(filter.id),
        };
      }

      if (filter.name) {
        where = {
          ...where,
          [Op.and]: Utils.ilike("pujas", "name", filter.name),
        };
      }

      if (filter.description) {
        where = {
          ...where,
          [Op.and]: Utils.ilike("pujas", "description", filter.description),
        };
      }

      if (filter.duration_hrsRange) {
        const [start, end] = filter.duration_hrsRange;

        if (start !== undefined && start !== null && start !== "") {
          where = {
            ...where,
            duration_hrs: {
              ...where.duration_hrs,
              [Op.gte]: start,
            },
          };
        }

        if (end !== undefined && end !== null && end !== "") {
          where = {
            ...where,
            duration_hrs: {
              ...where.duration_hrs,
              [Op.lte]: end,
            },
          };
        }
      }

      if (
        filter.active === true ||
        filter.active === "true" ||
        filter.active === false ||
        filter.active === "false"
      ) {
        where = {
          ...where,
          active: filter.active === true || filter.active === "true",
        };
      }

      if (filter.language) {
        where = {
          ...where,
          language: filter.language,
        };
      }

      if (filter.createdAtRange) {
        const [start, end] = filter.createdAtRange;

        if (start !== undefined && start !== null && start !== "") {
          where = {
            ...where,
            ["createdAt"]: {
              ...where.createdAt,
              [Op.gte]: start,
            },
          };
        }

        if (end !== undefined && end !== null && end !== "") {
          where = {
            ...where,
            ["createdAt"]: {
              ...where.createdAt,
              [Op.lte]: end,
            },
          };
        }
      }
    }

    let { rows, count } =
      await db.puja_model_procedure_mappings.findAndCountAll({
        where,
        include,
        distinct: true,
        limit: limit ? Number(limit) : undefined,
        offset: offset ? Number(offset) : undefined,
        order: [["order", "asc"]],
        transaction,
      });

    return { rows, count };
  }

  static async findBy(where, options) {
    const db = await getDbInstance();
    const transaction = (options && options.transaction) || undefined;

    const puja_model_procedure_mappings =
      await db.puja_model_procedure_mappings.findOne(
        { where },
        { transaction }
      );

    if (!puja_model_procedure_mappings) {
      return puja_model_procedure_mappings;
    }

    const output = puja_model_procedure_mappings.get({ plain: true });

    return output;
  }

  static async update(data) {
    const db = await getDbInstance();

    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const puja_model_procedure_mappings = await Promise.all(
      data.map(async (item) => {
        return await db.puja_model_procedure_mappings.update(
          {
            model_id: item.model_id,
            procedure_id: item.procedure_id,
            order: item.order,
          },
          { where: { id: item.id } }
        );
      })
    );

    return true;
  }

  static async remove(data) {
    const db = await getDbInstance();

    const deletedRows = await db.puja_model_procedure_mappings.destroy({
      where: { id: data },
      force: true,
    });

    return deletedRows;
  }
};
