/* eslint-disable @typescript-eslint/no-unused-vars */
const db = require("../models");
const Utils = require("../utils");
const Sequelize = require("sequelize");
const Op = Sequelize.Op;
const { models } = require("../models/index");
const getDbInstance = require("../initialize");

module.exports = class PujaProceduresDBApi {
  static async create(data, options) {
    const db = await getDbInstance();
    const currentUser = (options && options.currentUser) || { id: null };
    const transaction = (options && options.transaction) || undefined;

    const puja_procedure = await db.puja_procedures.create(
      {
        title: data.title || null,
        description: data.description || null,
        language: data.language || null,
        special_notes: data.special_notes || null,
      },
      { transaction }
    );

    return puja_procedure;
  }

  static async findAll(filters = {}) {
    try {
      const dbInstance = await getDbInstance();
      const limit = Math.max(1, parseInt(filters.limit) || 20);
      const page = Math.max(1, parseInt(filters.page) || 1);
      const offset = (page - 1) * limit;

      const where = {};

      // Add filters if provided
      if (filters.title) {
        where.title = filters.title;
      }
      if (filters.language) {
        where.language = filters.language;
      }

      const { rows, count } = await dbInstance.puja_procedures.findAndCountAll({
        where,
        attributes: [
          "id",
          "title",
          "description",
          "language",
          "special_notes",
          "createdAt",
          "updatedAt",
        ],
        limit,
        offset,
        raw: true,
      });

      return {
        rows,
        count,
        limit,
        offset,
        page: Math.ceil(offset / limit) + 1,
      };
    } catch (error) {
      console.error("Error in PujaProcedures.findAll:", error);
      throw error;
    }
  }

  static async findBy(where, options) {
    const db = await getDbInstance();
    const transaction = (options && options.transaction) || undefined;

    const puja_procedures = await db.puja_procedures.findOne(
      { where },
      { transaction }
    );

    if (!puja_procedures) {
      return puja_procedures;
    }

    const output = puja_procedures.get({ plain: true });

    return output;
  }

  static async update(data, id, options) {
    const db = await getDbInstance();
    const currentUser = (options && options.currentUser) || { id: null };
    const transaction = (options && options.transaction) || undefined;

    const puja_procedures = await db.puja_procedures.findByPk(id, {
      transaction,
    });

    await puja_procedures.update(
      {
        title: data.title || null,
        description: data.description || null,
        language: data.language || null,
        special_notes: data.special_notes || null,
      },
      { transaction }
    );

    return puja_procedures;
  }

  static async remove(id, options) {
    const db = await getDbInstance();
    const currentUser = (options && options.currentUser) || { id: null };
    const transaction = (options && options.transaction) || undefined;

    const puja_procedures = await db.puja_procedures.findByPk(id, options);

    await puja_procedures.destroy({
      transaction,
    });
    await Promise.all([
      db.puja_model_procedure_mappings.destroy(
        {
          where: {
            procedure_id: id,
          },
        },
        { transaction }
      ),

      db.booking_procedure_mappings.destroy(
        {
          where: {
            procedure_id: id,
          },
        },
        { transaction }
      ),
    ]);

    return puja_procedures;
  }
};
