const db = require("../models");
const Utils = require("../utils");
const getDbInstance = require("../initialize"); 
const Sequelize = db.Sequelize;
const Op = Sequelize.Op;

module.exports = class SubCategoriesDBApi {
  static async create(data, options = {}) {
    const db = await getDbInstance();
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const { currentUser = { id: null }, transaction } = options;

    const subCategory = await db.sub_categories.create(
      {
        name: data.name,
        description: data.description || null,
        category_id: data.category_id,
        images: data.images || null,
      },
      { transaction }
    );

    return subCategory;
  }

  static async findAll(filter = {}, options = {}) {
    const db = await getDbInstance();
    const { transaction } = options;
    let where = {};

    if (filter.name) {
      where = {
        ...where,
        [Op.and]: Utils.ilike("name", filter.name),
      };
    }

    const subCategories = await db.sub_categories.findAll({
      where,
      transaction,
    });

    return subCategories;
  }

  static async findBy(where, options = {}) {
    const db = await getDbInstance();
    const { transaction } = options;

    const subCategory = await db.sub_categories.findOne(
      { where },
      { transaction }
    );

    if (!subCategory) {
      return null;
    }

    return subCategory.get({ plain: true });
  }

  static async update(id, data, options = {}) {
    const db = await getDbInstance();
    const { transaction } = options;

    const subCategory = await db.sub_categories.findOne(
      { where: { id } },
      { transaction }
    );

    if (!subCategory) {
      throw new Error("Record not found");
    }

    await subCategory.update(
      {
        name: data.name,
        description: data.description || null,
        category_id: data.category_id,
        images: data.images || [],
      },
      { transaction }
    );

    return subCategory.get({ plain: true });
  }

  static async remove(id, options = {}) {
    const db = await getDbInstance();
    const { transaction } = options;

    const subCategory = await db.sub_categories.findOne(
      { where: { id } },
      { transaction }
    );

    if (!subCategory) {
      throw new Error("Record not found");
    }

    await subCategory.destroy({ transaction });
    return true;
  }
};
