/* eslint-disable no-undef */
module.exports = (sequelize, DataTypes) => {
  const Users = sequelize.define(
    "users",
    {
      id: {
        type: DataTypes.INTEGER,
        primaryKey: true,
        autoIncrement: true,
      },

      firstName: {
        type: DataTypes.TEXT,
      },

      lastName: {
        type: DataTypes.TEXT,
      },

      phoneNumber: {
        type: DataTypes.TEXT,
      },

      email: {
        type: DataTypes.TEXT,
      },

      role: {
        type: DataTypes.ENUM,
        values: ["admin", "user"],
      },

      disabled: {
        type: DataTypes.BOOLEAN,
        allowNull: false,
        defaultValue: false,
      },

      password: {
        type: DataTypes.TEXT,
      },

      emailVerified: {
        type: DataTypes.BOOLEAN,
        allowNull: false,
        defaultValue: false,
      },

      emailVerificationToken: {
        type: DataTypes.TEXT,
      },

      emailVerificationTokenExpiresAt: {
        type: DataTypes.DATE,
      },

      passwordResetToken: {
        type: DataTypes.TEXT,
      },

      passwordResetTokenExpiresAt: {
        type: DataTypes.DATE,
      },

      provider: {
        type: DataTypes.TEXT,
      },

      type: {
        type: DataTypes.ENUM,
        values: ["SUPER_ADMIN", "PRIEST"],
      },

      email_verified_at: {
        type: DataTypes.DATE,
      },

      first_time_login: {
        type: DataTypes.INTEGER,
      },

      forgot_password_token: {
        type: DataTypes.TEXT,
      },

      remember_token: {
        type: DataTypes.TEXT,
      },

      forgot_password_token_timestamp: {
        type: DataTypes.DATE,
      },

      is_active: {
        type: DataTypes.INTEGER,
      },

      importHash: {
        type: DataTypes.STRING(255),
        allowNull: true,
        unique: true,
      },
    },
    {
      timestamps: true,
      paranoid: true,
      freezeTableName: true,
    }
  );

  Users.associate = (db) => {
    Users.hasMany(db.file, {
      as: "avatar",
      foreignKey: "belongsToId",
      constraints: false,
      scope: {
        belongsTo: Users.getTableName(),
        belongsToColumn: "avatar",
      },
    });

    db.users.belongsTo(db.users, {
      as: "createdBy",
    });

    db.users.belongsTo(db.users, {
      as: "updatedBy",
    });
  };

  Users.beforeCreate((users) => {
    users = trimStringFields(users);

    if (
      users.provider !== providers.LOCAL &&
      Object.values(providers).indexOf(users.provider) > -1
    ) {
      users.emailVerified = true;

      if (!users.password) {
        const password = crypto.randomBytes(20).toString("hex");

        const hashedPassword = bcrypt.hashSync(
          password,
          config.bcrypt.saltRounds
        );

        users.password = hashedPassword;
      }
    }
  });

  Users.beforeUpdate((users) => {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    users = trimStringFields(users);
  });

  return Users;
};

function trimStringFields(users) {
  users.email = users.email.trim();

  users.firstName = users.firstName ? users.firstName.trim() : null;

  users.lastName = users.lastName ? users.lastName.trim() : null;

  return users;
}
