import {
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  ManyToOne,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Bookings } from './bookings';

@Entity('booking_transactions')
export class BookingTransactions {
  @PrimaryGeneratedColumn('uuid')
  readonly id?: string;

  @Column({ name: 'booking_id' })
  readonly booking_id?: number;

  @Column({ name: 'transaction_id' })
  readonly transaction_id?: string;

  @Column({ name: 'razorpay_id' })
  readonly razorpay_id?: string;

  @Column({ name: 'paidamount' })
  readonly paidAmount?: number;

  @Column({ name: 'totalamount' })
  readonly totalAmount?: number;

  @Column({
    name: 'payment_status',
    type: 'enum',
    enum: ['success', 'failure'],
  })
  readonly payment_status?: 'success' | 'failure';

  @Column({ name: 'payment_type', type: 'enum', enum: ['poojari', 'website'] })
  readonly payment_type?: 'poojari' | 'website';

  /**
   * added createdAt and updatedAt fields in the db
   */

  @CreateDateColumn()
    createdAt: Date;

  @UpdateDateColumn()
    updatedAt: Date;

  @ManyToOne(() => Bookings, (model) => model.bookingtransactions)
  @JoinColumn({ name: 'booking_id' })
  readonly bookings!: Bookings;

  constructor(
    id?: string,
    booking_id?: number,
    transaction_id?: string,
    razorpay_id?: string,
    paidAmount?: number,
    totalAmount?: number,
    payment_status?: 'success' | 'failure',
    payment_type?: 'poojari' | 'website',
    updatedAt?: Date,
    createdAt?: Date
  ) {
    this.id = id;
    this.booking_id = booking_id;
    this.transaction_id = transaction_id;
    this.razorpay_id = razorpay_id;
    this.paidAmount = paidAmount;
    this.totalAmount = totalAmount;
    this.payment_status = payment_status;
    this.payment_type = payment_type;
    this.updatedAt = updatedAt || new Date();
    this.createdAt = createdAt || new Date();
  }
}
