import { Column, Entity, JoinColumn, OneToMany, PrimaryColumn } from 'typeorm';
import { BookingParticipants } from './booking-participants';
import { Bookings } from './bookings';
import { KaruserPujariMappings } from './karuser_pujari_mappings';

@Entity('karusers')
export class KarishyeUsers {
  @PrimaryColumn({ name: 'id' })
  readonly id: string;

  @Column({ name: 'name' })
  readonly name?: string;

  @Column({ name: 'surname' })
  readonly surname?: string;

  @Column({ name: 'date_of_birth' })
  readonly dateOfBirth?: Date;

  @Column({ name: 'date_of_registration' })
  readonly dateOfRegistration?: Date;

  @Column({ name: 'address_line1' })
  readonly addressLine1?: string;

  @Column({ name: 'address_line2' })
  readonly addressLine2?: string;

  @Column({ name: 'city' })
  readonly city?: string;

  @Column({ name: 'pincode' })
  readonly pincode?: string;

  @Column({ name: 'country' })
  readonly country?: string;

  @Column({ name: 'state' })
  readonly state?: string;

  @Column({ name: 'gothram' })
  readonly gothram?: string;

  @Column({ name: 'nakshatram' })
  readonly nakshatram?: string;

  @Column({ name: 'email_id' })
  readonly emailId?: string;

  @Column({ name: 'phone_number' })
  readonly phoneNumber?: string;

  @Column({ name: 'gender' })
  readonly gender?: string;

  @Column({ name: 'is_karishye_sourced' })
  readonly isKarishyeSourced?: boolean;

  @Column({ name: 'updatedAt', type: 'timestamp' })
  readonly updatedAt?: Date;

  @Column({ name: 'deletedAt', type: 'timestamp' })
  readonly deletedAt?: Date;

  @Column({ name: 'createdAt', type: 'timestamp' })
  readonly createdAt?: Date;

  @Column({ name: 'importHash', type: 'varchar' })
  readonly importHash?: string;

  @Column({ name: 'createdById', type: 'char' })
  readonly createdById?: string;

  @Column({ name: 'updatedById', type: 'char' })
  readonly updatedById?: string;

  @OneToMany(() => Bookings, (userref) => userref.karishye_users)
  readonly bookings!: Bookings;

  @OneToMany(() => BookingParticipants, (bookingparti) => bookingparti.memberid)
  readonly participant!: BookingParticipants;

  @OneToMany(() => BookingParticipants, (bookingparti) => bookingparti.userid)
  readonly participants!: BookingParticipants;

  @OneToMany(() => KaruserPujariMappings, (mapping) => mapping.karuser)
  @JoinColumn({ name: 'id' })
    karuserPujari!: KaruserPujariMappings;

  constructor(
    id: string,
    name?: string,
    surname?: string,
    dateOfBirth?: Date,
    dateOfRegistration?: Date,
    addressLine1?: string,
    addressLine2?: string,
    city?: string,
    state?: string,
    pincode?: string,
    country?: string,
    gothram?: string,
    nakshatram?: string,
    emailId?: string,
    phoneNumber?: string,
    gender?: string,
    isKarishyeSourced?: boolean,
    updatedAt?: Date,
    createdAt?: Date,
    deletedAt?: Date,
    importHash?: string,
    createdById?: string,
    updatedById?: string
  ) {
    this.id = id;
    this.name = name;
    this.surname = surname;
    this.dateOfBirth = dateOfBirth;
    this.dateOfRegistration = dateOfRegistration;
    this.addressLine1 = addressLine1;
    this.addressLine2 = addressLine2;
    this.city = city;
    this.state = state;
    this.pincode = pincode;
    this.country = country;
    this.gothram = gothram;
    this.nakshatram = nakshatram;
    this.emailId = emailId;
    this.phoneNumber = phoneNumber;
    this.gender = gender;
    this.isKarishyeSourced = isKarishyeSourced;
    this.updatedAt = updatedAt;
    this.deletedAt = deletedAt;
    this.importHash = importHash;
    this.createdAt = createdAt;
    this.createdById = createdById;
    this.updatedById = updatedById;
  }
}
