import {
  Column,
  Entity,
  JoinColumn,
  OneToMany,
  OneToOne,
  PrimaryColumn,
} from 'typeorm';
import { Bookings } from './bookings';
import { PujariApplications } from './pujari_applications';
@Entity('pujaris')
export class Pujaris {
  @PrimaryColumn({ name: 'id' })
  readonly id: number;

  @Column({ name: 'application_id' })
  readonly applicationId?: number;

  @Column({ name: 'name' })
  readonly name?: string;

  @Column({ name: 'surname' })
  readonly surname?: string;

  @Column({ name: 'date_of_birth' })
  readonly dateOfBirth?: Date;

  @Column({ name: 'date_of_joining' })
  readonly dateOfJoining?: Date;

  @Column({ name: 'qualification' })
  readonly qualification?: string;

  @Column({ name: 'experience_yrs' })
  readonly experienceYrs?: number;

  @Column({ name: 'address' })
  readonly address?: string;

  @Column({ name: 'email_id' })
  readonly emailId?: string;

  @Column({ name: 'phone_number' })
  readonly phoneNumber?: string;

  @Column({ name: 'razorpay_id' })
  readonly razorpayId?: string;

  @Column({ name: 'photo' })
  readonly photo?: string;

  @Column({ name: 'gender' })
  readonly gender?: string;

  @Column({ name: 'language' })
  readonly language?: string;

  @Column({ name: 'does_online_pujas' })
  readonly doesOnlinePujas?: boolean;

  @Column({ name: 'is_ready_to_travel' })
  readonly isReadyToTravel?: boolean;

  @Column({ name: 'primary_city' })
  readonly primaryCity?: string;

  @Column({ name: 'is_active' })
  readonly isActive?: boolean;

  @Column({ name: 'updatedAt', type: 'timestamp' })
  readonly updatedAt?: Date;

  @Column({ name: 'deletedAt', type: 'timestamp' })
  readonly deletedAt?: Date;

  @Column({ name: 'createdAt', type: 'timestamp' })
  readonly createdAt?: Date;

  @Column({ name: 'importHash', type: 'varchar' })
  readonly importHash?: string;

  @Column({ name: 'createdById', type: 'char' })
  readonly createdById?: string;

  @Column({ name: 'updatedById', type: 'char' })
  readonly updatedById?: string;

  @OneToMany(() => Bookings, (bookingref) => bookingref.pujaris)
  readonly bookings!: Bookings;

  @OneToOne(
    () => PujariApplications,
    (pujarismapping) => pujarismapping.pujaris
  )
  @JoinColumn({ name: 'application_id' })
  readonly pujariapplications!: PujariApplications;

  constructor(
    id: number,
    applicationId?: number,
    name?: string,
    surname?: string,
    dateOfBirth?: Date,
    dateOfJoining?: Date,
    qualification?: string,
    experienceYrs?: number,
    address?: string,
    emailId?: string,
    phoneNumber?: string,
    razorpayId?: string,
    photo?: string,
    gender?: string,
    language?: string,
    doesOnlinePujas?: boolean,
    isReadyToTravel?: boolean,
    primaryCity?: string,
    isActive?: boolean,
    updatedAt?: Date,
    createdAt?: Date,
    deletedAt?: Date,
    importHash?: string,
    createdById?: string,
    updatedById?: string
  ) {
    this.id = id;
    this.applicationId = applicationId;
    this.name = name;
    this.surname = surname;
    this.dateOfBirth = dateOfBirth;
    this.dateOfJoining = dateOfJoining;
    this.qualification = qualification;
    this.experienceYrs = experienceYrs;
    this.address = address;
    this.emailId = emailId;
    this.phoneNumber = phoneNumber;
    this.razorpayId = razorpayId;
    this.photo = photo;
    this.gender = gender;
    this.language = language;
    this.doesOnlinePujas = doesOnlinePujas;
    this.isReadyToTravel = isReadyToTravel;
    this.primaryCity = primaryCity;
    this.isActive = isActive;
    this.updatedAt = updatedAt;
    this.deletedAt = deletedAt;
    this.importHash = importHash;
    this.createdAt = createdAt;
    this.createdById = createdById;
    this.updatedById = updatedById;
  }
}
