import { Injectable, Logger } from '@nestjs/common';
import { errorResponse, sendResponse } from 'src/common/common-utils';
import { AppDataSource } from 'src/common/db-utils';
import { KarishyeUsers } from 'src/entities';
import { Pujaris } from 'src/entities/pujaris';
import { TwilioService } from 'src/pujari/users/services/twilio/twilio.service';
import { UserPayload } from '../pujari/users/models/twilio.dto';
@Injectable()
export class LoginService {
  logger: Logger;

  constructor() {
    this.logger = new Logger();
  }
  twilio: TwilioService = new TwilioService();

  async userLogin(data: UserPayload) {
    try {
      const userRepo = AppDataSource.getRepository(KarishyeUsers);
      const pujariRepo = AppDataSource.getRepository(Pujaris);

      let userInfo: any | null;
      if (data.isPujari === 'true') {
        userInfo = await pujariRepo.findOne({
          where: { phoneNumber: data.phoneNumber },
        });
        this.logger.log('userInfo', userInfo);
      } else {
        userInfo = await userRepo.findOne({
          where: { phoneNumber: data.phoneNumber },
        });
      }

      if (userInfo) {
        return this.twilio
          .sendOTP(data)
          .then((optStatus: any) => {
            if (optStatus.statusCode === 500) {
              return errorResponse(optStatus);
            }
            return sendResponse({ optStatus });
          })
          .catch((err: any) => {
            this.logger.log('err', err);
            return errorResponse(err);
          });
      } else {
        throw new Error('Mobile number not found');
      }
    } catch (err) {
      this.logger.error('Error in userLogin', err);
      return errorResponse(err);
    }
  }

  async userSignUp(data: UserPayload) {
    try {
      const userRepo = AppDataSource.getRepository(KarishyeUsers);
      const pujariRepo = AppDataSource.getRepository(Pujaris);

      let userInfo: any | null;
      if (data.isPujari === 'true') {
        userInfo = await pujariRepo.findOne({
          where: { phoneNumber: data.phoneNumber },
        });
      } else {
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        userInfo = await userRepo.findOne({
          where: { phoneNumber: data.phoneNumber },
        });
      }

      return this.twilio
        .sendOTP(data)
        .then((optStatus: any) => {
          if (optStatus.statusCode === 500) {
            return errorResponse(optStatus);
          }
          return sendResponse({ optStatus });
        })
        .catch((err: any) => {
          this.logger.error('Error sending OTP', err);
          return errorResponse(err);
        });
    } catch (err) {
      this.logger.error('Error in userSignUp', err);
      return errorResponse(err);
    }
  }

  async validateOTP(data: UserPayload) {
    try {
      const userRepo = AppDataSource.getRepository(KarishyeUsers);
      const pujariRepo = AppDataSource.getRepository(Pujaris);

      let userInfo: any | null;

      if (data.isPujari === 'true') {
        userInfo = await pujariRepo.findOne({
          where: { phoneNumber: data.phoneNumber },
        });
      } else {
        userInfo = await userRepo.findOne({
          where: { phoneNumber: data.phoneNumber },
        });
      }

      if (
        // eslint-disable-next-line no-constant-condition
        1
        //userInfo
      ) {
        return this.twilio
          .verifyOTP(data)
          .then((optStatus: any) => {
            if (optStatus.statusCode === 500) {
              return errorResponse(optStatus);
            }
            return sendResponse({ userInfo, optStatus });
          })
          .catch((err: any) => {
            this.logger.error('Error verifying OTP', err);
            return errorResponse(err);
          });
      } else {
        throw new Error('Mobile number not found');
      }
    } catch (err) {
      this.logger.error('Error in validateOTP', err);
      return errorResponse(err);
    }
  }
}
