import { ApiProperty, ApiPropertyOptional } from '@nestjs/swagger';
import {
  IsEnum,
  IsNotEmpty, IsOptional,
  IsString
} from 'class-validator';
import { EVENT_TYPE } from 'src/common/constants';
import { Pujas } from 'src/entities';
import { PujaHistory } from 'src/entities/puja_history';

export class GetPujasDto {
  @ApiPropertyOptional()
  @IsOptional()
  public id?: number;

  @ApiPropertyOptional()
  @IsOptional()
  public history?: string;
}

export class GetPujaModelsDto {
  @ApiProperty()
  @IsNotEmpty()
  public pujaId: number;

  @ApiPropertyOptional()
  @IsOptional()
  public id?: number;
}

export class PujaHistoryListData {
  @ApiProperty({
    type: Pujas,
  })
  public pujaData: Pujas;

  @ApiProperty({
    type: PujaHistory,
    isArray: true,
  })
  public pujaHistory: PujaHistory[];
}

export class GetPujasPayload {
  @ApiProperty({ type: String, required: false })
  @IsOptional()
  @IsString()
    id?: string;

  @ApiProperty({ type: String, required: false })
  @IsOptional()
  @IsString()
    categoryId?: number;

  @ApiProperty({ type: String, required: false })
  @IsOptional()
  @IsString()
    subCategoryId?: number;

  @ApiProperty({ type: EVENT_TYPE, required: false })
  @IsOptional()
  @IsEnum(EVENT_TYPE)
    mode?: EVENT_TYPE;

  @ApiProperty({ type: String, required: false })
  @IsOptional()
  @IsString()
    history?: string;
}
